=========
Changelog
=========

This document records all notable changes to 
`SciPlot-PyQt <https://github.com/CCampJr/SciPlot-PyQt>`_.

This project adheres to `PEP 440 -- Version Identification 
and Dependency Specification <https://www.python.org/dev/peps/pep-0440/>`_.

0.2.3 (21-11-29)
-----------------

- Bug fix

0.2.2 (19-05-20)
-----------------

-   Added control to figure DPI and figsize
-   Minor tweaks to UI layout
-   Address compatibility with Matplotlib 2.*/3.*

0.2.1 (17-12-07)
----------------

-   CHANGELOG added
-   Continuous integration with `Travis CI <https://travis-ci.org/CCampJr/SciPlot-PyQt>`_ 
    and `Appveyor <https://ci.appveyor.com/project/CCampJr/sciplot-pyqt>`_.
-   Stability improvements
-   Improved support for Matplotlib 1.5.* and 2.*

0.1.4 (17-09-26)
----------------

-   Added concurrent support for both Matplotlib 1.5.* and 2.*


0.1.3 (17-01-19)
----------------

-   Export bars, lines, and fill-betweens to CSV files
-   Total re-write of plot containers-- now a Plot-ID and Plot-Type system
-   Lots of improvements that were not catalogued

0.1.2 (16-07-22)
----------------

-   Lots of improvements that were not catalogued
-   Can now pass MPL kwargs through sciplot instantiation


0.1.1 (16-07-21)
----------------

-   SciPlot can now be embedded in other applications as a widget
-   Added bar plots


0.1 (16-07-21)
--------------

-   Initial stable(-ish) version
-   Deployed to PyPi